#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 time-manager
version:              0.0.1
visibility:           public
id:                   time-manager-0.0.1-FlSUlTCvRGL872tnwrfop
key:                  time-manager-0.0.1-FlSUlTCvRGL872tnwrfop
license:              MIT
maintainer:           kazu@iij.ad.jp
author:               Michael Snoyman and Kazu Yamamoto
stability:            Stable
homepage:             http://github.com/yesodweb/wai
synopsis:             Scalable timer
description:          Scalable timer functions provided by a timer manager.
category:             System
abi:                  e1e58080496602bf3076195360247161
exposed:              True
exposed-modules:      System.TimeManager
import-dirs:          /usr/lib/ghc-9.6.6/site-local/time-manager-0.0.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/time-manager-0.0.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/time-manager-0.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.6.6/time-manager-0.0.1
hs-libraries:         HStime-manager-0.0.1-FlSUlTCvRGL872tnwrfop
depends:
    auto-update-0.1.6-E5aLWRUFo6vLtvWCrvKB9n base-4.18.2.1
    unliftio-0.2.25.1-JOKqT5DcdDFKqQgMQFlxcn

haddock-interfaces:
    /usr/share/doc/haskell-time-manager/html/time-manager.haddock

haddock-html:         /usr/share/doc/haskell-time-manager/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

